; SYS-Disk-3.asm V1.1
;
; zum Bearbeiten der Systemspuren auf Monitorebene
;
; Assembler 8085-Simulator-ID V4.93 Oshonsoft (Vladimir Soso)
; Editor 	Notepad++ TAB=6
;
;
; 16.01.2023	Umruestung auf Monitormodule
;			 io231	IO-Adressen
;			 spm231	Monitor Sprungleiste
;			 spv231	Video Monitor Sprungleiste
;			 sys231	RAM Belegung
;			 spex231	Externe Programme
;
; 28.01.2022	Beschreibung vervollständigt
; 16.02.2021	new15 Vorbesetzungen auf CT180
; 09.02.2021	new14 OK! SS, DS
; 05.02.2021	new13 ! Format SS OK, DS ab 9 Sektoren wird die Spur nicht
;			weitergeschaltet
; 02.02.2021	new12 ! Formate SS OK; DS Falscher Track
; 28.01.2021	Sektor lese/schreiben
; 27.01.2021	Blocklesen schreiben mit Moppel OK
; 27.01.2021	Parameter Eingabe mit Prüfung
;-----------------------------------------------------------------------------
;
; Hiermit können auf Monitorebene die Systemspuren bearbeitet werden
;
; + es koennen alle Formate des WD1770 gelesen/geschrieben werden
;   auch Formatuebergreifend
;
; + zwischen lesen und schreiben kann das BIOS über den Intel-Hex-Lader ausgetauscht werden
;
; + der Boot-Loader auf Track 0 Sektor 1 kann
;   auf der gleichen weise manipuliert werden
;
; ! Bei DS-Disketten wird erst Seite 0 und anschliessend Seite 1 gelesen/geschrieben
;
; Menuepunkte:
;
;	m = zurueck zum Monitor		-> Ruecksprung zum Monitor
;
;	p = Parameter eingeben
;		Quelle Ziel LW	>1,1	-> Laufwerke auswaehlen 0=A
;		Track Sek	>0,2	-> Start Trak und Sektor waehlen
;		Anzahl Sek	>9	-> Anzahl der Sektoren (in Hex)
;		Format		>0,1,10	-> SS/DS, Sek.Laenge, Anzahl Sek pro Track (Moppel)
;		Format		>1,3,5	(Beispiel fuer das MC-Format)
; 		  SS/DS:
;			0=SS
;			1=DS
;		  Sek-Laenge:
;			0 =  128 Byte
;			1 =  256 Byte
;			2 =  512 byte
;			3 = 1024 Byte
;		  Anz.Sek per Track:
;		   	5 Sek bei 1024 Byte pro. Sektor;
;
;		Zieladresse	>D400	-> in Hex
;
;	r = Systemspuren lesen		-> mit den angegebenen Parametern
;
;	i = Intel-Hex			-> Hex-Datei laden (Org beachten)
;
;	w = Systemspuren schreiben	-> mit den angegebenen Parametern
;
;	h = Hilfe			-> Menuepunkte ausgeben
;
;
;
;-----------------------------------------------------------------------------
;
; Vorspann Parameterbereich
;
; Monitorprogramme
;
; Adressen vom Monitor #0
;
rst0_m	equ	0000h		; RST0	--> Kaltstart
bcpm_m	equ	0003h		; Boot CP/M
fquarz_m	equ	0006h		; Taktfrequenz in MHz
timprl_m	equ	0007h		; Prellzeit der Tastatur
rst1_m  	equ 	0008h		; RST1
dely1_m	equ 	000bh		; DELY1 --> 1ms Laufzeit
prtbdr_m	equ	000eh		; Baudrate fuer Drucker	= 4800Bd
rst2_m	equ 	0010h		; RST2
dely100_m 	equ 	0013h		; DELY100 --> mit SSG-Anzeige
casbdr_m	equ	0016h		; Baudrate fuer Cassetten = 1200Bd
rst3_m	equ 	0018h		; RST3
onesec_m 	equ 	001bh		; ONESEC --> 1s Laufzeit
v24bdr_m	equ	001eh		; Baudrate fuer V24-Schnittstelle = 4800Bd
rst4_m	equ 	0020h		; RST4
trap_m	equ	0024h		; TRAP	--> FDC-Routinen
rst5_m	equ 	0028h		; RST5
rst55_m	equ 	002ch		; RST5.5 --> FDC-Routinen
rst6_m	equ 	0030h		; RST6
rst65_m	equ 	0034h		; RST6.5
rst7_m	equ 	0038h		; RST7
rst75_m	equ 	003ch		; RST7.5
mvers_m	equ	003fh		; Monitorversion z.B. 55 fuer Version 5.5
ihex		equ 	0040h		; zum Intel-Hex-Lader
ci		equ 	0043h		; CI ASCII-Tastatur abfragen (A)
ri_m		equ 	0046h		; RI ein Byte von Kasetteninterface empfangen (A)
co		equ 	0049h		; CO Inhalt(C) ASCII an Bildschirm (UPDATE)
po_m		equ 	004ch		; PO Inalt (C) auf Kasetteninterface (1200Bd)
lo_m		equ 	004fh		; LO Inalt (C) ASCII-Zeichen V24 (4800Bd)
csts	 	equ 	0052h		; CSTS Status ASCII-Tastatur
					;	 gedrueckt Z=0 sonst Z=1
csinit_m	equ 	0055h		;
loinit_m	equ 	0058h		; LO-Init
maxram_m	equ 	005bh		; MEMCHK Speichertest (AB)max Adressen
prtmod_m	equ	005eh		; Betriebsart
;					; (8bit,1Stop,ohne Paritaet, Takt/16) =15h
casmod_m	equ	005fh		; Cassettenbetriebsart
					; (8daten, ohne Paritaet) = 10h
v24mod_m	equ	0060h		; V24 Betriebsart
					; (8bit,1Stop,ohne Paritaet, Takt/16) = 15h
time_m	equ 	0061h		; TI Uhrzeit lesen ASCII in Buffer
v24ini_m	equ 	0064h		; wird ueber PCHL aus Videomonitor angesprungen
cnvbyt_m 	equ 	0067h		; SSG-Umsetzen
reles_m	equ 	006ah		; HEX-Tastatur auf Loslassen warten
press_m  	equ 	006dh		;  "           auf Drücken warten
hhkey_m	equ 	0070h		; HEX-Input
cckey_m  	equ 	0073h		; CMD-Input
datset_m 	equ 	0076h		; Daten-Mode einstellen
writur_m	equ 	0079h		; WRITUR Uhrzeit stellen
					; (HL)Std,min, (BC)Wochentag, (DE)Monat,Jahr
readur_m	equ 	007ch		; READUR Uhrzeit lesen BCD(HL)Adresse
save_m   	equ 	007fh		; Register vorbereiten/sichern
restor_m	equ 	0082h		; Registersatz laden, Start
fill_m	equ 	0085h		; FILL Speicher fuellen (SRCBEG,SRCEND,DSTBEG)
copy_m 	equ 	0088h		; COPY Speicher kopieren (SRCBEG,SRCEND,DSTBEG)
casot_m	equ 	008bh		; Casetten Ausgabe
casin_m	equ 	008eh		; Eingabe
exchan_m	equ 	0091h		; Copy mit Adressumsetzung
ezudsp_m	equ 	0094h		; Uhr in SSG-Anzeige
dspacc_m	equ 	0097h		; (ACC) darstellen
dsphl_m	equ 	009ah		; (HL) darstellen
dsperr_m 	equ 	009dh		; Fehleranzeige
;
;
; Video-Monitor			Eprom-Platz #1
;
kalt_v	equ	1000h		; Kaltstart
warm_v	equ	1003h		; Warmstart
co_v		equ	1006h		; Console Output
ci_v		equ	1009h		; Console Input
csts_v	equ	100Ch		; Console Status
break_v	equ	100Fh		; Programmabbruch?
parin_v	equ	1012h		; Parameter einlesen
hxtest_v	equ	1015h		; ASCII/HEX-Umsetzung
compar_v	equ	1018h		; MEM-Differenz
sample	equ	101Bh		; Zeichenvorrat ausgeben
v24ot_v 	equ	101Eh		; PO über V.24
string_v	equ	1021h		; Video-Ausgabe
v24in_v 	equ	1024h		; RI über V.24
error_v 	equ	1027h		; Fehlermeldung
undrln_v	equ	102Ah		; String invers
clrvid_v	equ	102Dh		; Clear Video-RAM;
clrlin_v	equ	1030h		; Bildzeile löschenassembler
crspos_v	equ	1033h		; Cursor positionieren;
crson_v 	equ	1036h		; Cursor einschalten;
crsoff_v	equ	1039h		; Cursor ausschaltendisass
adrot_v 	equ	103Ch		; (H&L) ausgeben;
bytot_v 	equ	103Fh		; (ACC) ausgeben; Editor
bytbin_v	equ	1042h		; (ACC) binaer ausgeben;
regsot_v	equ	1045h		; (Regs) ausgebenedit
;
; Multi-IO-Karte
;
;	1 x Timer
;		- Baudraten V24
; 	2 x V24
;		- COM1
;		- COM2
;	2 x PIO
;		- 8 DIP-Schalter fuer IO-Byte
;		- Systemuhr
;		- Centronis
;
;--------------------------------------------------------------------
;
;
; Floppy-Controller		EPROM-Platz #2
;
;
fdck_f: 	equ	2000h		; FDCK: FDC-Routinen Kaltstart
fdcw_f: 	equ	2003h		; WARM: FDC-Routinen Warmstart
wrblk_f:	equ	2006h		; Block schreiben
rdblk_f	equ	2009h		;       lesen
wrsek_f:	equ	200ch		; Sektor schreiben
rdsek_f:	equ	200fh		;        lesen
cpyblk_f:	equ	2012h		; 32k Block kopieren
;settr_f:	equ	h		;
;setsek_f:	equ	h		;

;rsek_f:	equ	268eh		;
;
; CP/M
;
ccp:		equ	0d400h		;
bios:		equ	0ea00h
;

; PIO1 Centronics und UNI-IO Kanal
;
pio1a		equ	03h		; Centronic's
pio1b		equ	13h		; frei
pio1c		equ	23h		; Steuerung Centronics
pio1s		equ	33h		; Steuerregister
bap1		equ	0abh		; 1010 1011
					; Kanal A Modus 1 Ausgabe, Kanal B Modus 0 Eingabe
					; Kanal C Eingabe
;
; PIO2 IO-Byte und Systemuhr
;
pio2a		equ	43h		;
pio2b		equ	53h		; IO-byte DIP-Schalter			<--
pio2c		equ	63h		; RTC 58321 Control
pio2s		equ	73h		; Steuerregister
bap2		equ	82h		; 1000 0010
bap2rdu	equ	92h		; 1001 0010
;
;
iobyte	equ	pio2b		; IO-Adresse DIP-Schalter
;
;
;	Bit7 6 5 4 3 2 1 0
;	   : : : : : : : :
;        : : : : : : : + - 0= Moppel-Tastatur 	1= CI/CSTS 1.87er V24-CON
;        : : : : : : + - - 0= CO Moppel Video	1= CO
;        + - - - - - - - - 0= Moppel-Modus	1= CP/M Loader
;
;
; Timer
;
tim0		equ	83h		; BD-Rate fuer com1
tim1		equ	93h		; BD-Rate fuer com2
tim2		equ	0a3h		; frei
tims		equ	0b3h		; Steuerregister
					; Timer0-2 als BCD-Zaehler, Rechteckgenerator,
					; erst Timewert-Low, dann Timewert-High laden
bati0		equ	37h		; 0011 0111
bati1		equ	77h		; 0111 0111
bati2		equ	0b7h		; 1011 0111
;
; V24
;
com1s		equ	0c3h		; Steuerregister
com1d		equ	0d3h		; Daten com1
bacom1	equ	15h		; Betriebsart (8bit,1Stop,ohne Paritaet, Takt/16)		;
;
com2s		equ	0e3h		; Steuerregister
com2d		equ	0f3h		; Daten com2
bacom2	equ	15h		; Betriebsart (8bit,1Stop,ohne Paritaet, Takt/16)
;
baud		equ	0020h		; 9600Bd fuer Muti-IO-Karte
;
;-------------------------------------------------------------------
;
; CF-Karte mit ATMega 644
;
cf_a		equ 	0cah		; Daten Ein-Ausgabe
cf_b		equ	0dah		; Daten Ausgabe B
cf_c		equ	0eah		; Daten Steuerung C
cf_ctl	equ	0fah		; Steuerwort
;
cf_ba		equ	0c1h		; Betriebsart
;					; Kanal A bidirektional, Handshake Kanal C
;-------------------------------------------------------------------
;
; IDE-Karte
; Entwickelt aus IDETOOL von Alfred Klichs 2022,
; Paul's 8051 Code Library, Paul Stoffregen 2005
; https://www.pjrc.com/tech/8051/ide/
;
;
;
; IO-Adressen fuer PIO 8255
;
PIO_IDE		EQU	058H		; PIO I/O Adresse
;
PIO_LSB		EQU	0 + PIO_IDE ; Port A
PIO_MSB		EQU	1 + PIO_IDE ; Port B
PIO_CTL		EQU	2 + PIO_IDE ; Port C
PIO_CFG		EQU	3 + PIO_IDE ; I/O modus
;
PIO_RDW		EQU	10010010B 	; Port A+B input, Port C output
PIO_WR		EQU	10000000B 	; Port A+B+C output
;
IDE_DRV		EQU	11100000B 	; select the device
			; x1x00000b LBA master
			; x1x10000b LBA slave
			; x0x00000b CHS master
			; x0x10000b CHS slave
;					; Kanal B als Ausgabe
;
;--------------------------------------------------------------------
;
; 1. 87er V24-Schnittstellenkarte
; als allgemeine DFUe- Schnittstelle
;
; ACIA 6850
;
com0s		equ	0e9h		; ACIA 6850 Control/Statusregister
com0d		equ	0f9h		;           Daten lesen/schreiben
;
; Mode-Funktionen
; Auswahl der Schnittstellen
;
;	Bit7 6 5 4 3 2 1 0
;	   : : : : : : : :
;        : : : : : : : + - /Relais 0 (0 = Relais aktiv)
;        : : : : : : + - - /Relais 1 (0 = Relais aktiv)
;        : : : : : + - - - Mod 2 = (20mA) (1= Ausgang aktiv)
;        : : : : + - - - - Mod 3 = (v24)
;	   : : : + - - - - - Mod 4 = (DTR)
;	   : : + - - - - - - Mod 5 = (PRT)
;	   0 0 - - - - - - - = 20mA
;	   0 1 - - - - - - - = V24
;	   1 0 - - - - - - - = PRT
;        1 1 - - - - - - - = Kassette
;
;
;	z.B. 	Mod 4Bh an cs_modex	= V24
;		Mod 43h an cs_modex	= V24 Printer an rückwertigen Buchse
;
; Modus Wahlschalter
;
cs_mode	equ	0a9h		; Modus (Eingangswahlschalter)
cs_bell	equ	0b9h		; Bell  (Schnarre)
;
; Timer 8253
;
timer_0s	equ	0d9h		; Timer 8253 Controlregister
timer_00	equ	89h		;        Zaehler 0
timer_01	equ	99h		;	   Zaehler 1 * nicht benutzt
timer_02	equ	0c9h		;	   Zaehler 2 * nicht benutzt
;
;
;--------------------------------------------------------------------
;
; 2. 87er V24-Schnittstellenkarte
; als Console anstelle der Moppeltastatur und Bildschirm
;
; ! Adressbereich identisch mit Paralellschnittstelle !
;
cons		equ	0e8h		; ACIA 6850 Control/Statusregister
cond		equ	0f8h		;           Daten lesen/schreiben
;
cs_mode1	equ	0a8h		; Modus (Eingangswahlschalter)
cs_bell1	equ	0b8h		; Bell  (Schnarre)
;
timer_1s	equ	0d9h		; Timer 8253 Controlregister
timer_10	equ	88h		;        Zaehler 0
timer_11	equ	98h		;	   Zaehler 1 * nicht benutzt
timer_12	equ	0c8h		;	   Zaehler 2 * nicht benutzt
;
startbd	equ	0020		; Startbaudrate 9600Bd
;
;--------------------------------------------------------------------
;
; RAM-Bank Umschaltung fuer CP/M Betrieb
;
bank		equ	24h		; Port fuer Bankumschaltung
;
;					; 81h an 24h 0000-3fffh EPROM/VID
;					;            4000-ffffh RAM
;					; 01h an 24h 0000-ffffh RAM
;
;--------------------------------------------------------------------
;
; FDC-Karte
;
fdc_sel	equ	40h		; Floppy Selekt-Byte
fdc_ctl	equ	48h		; WD1720 Controlregister
fdc_sp	equ	49h		; Spurregister
fdc_sek	equ	4ah		; Sektorregister
fdc_dat	equ	4bh		; Datenregister
;
;
;--------------------------------------------------------------------
;
; Parallelschnittstelle (keine ECB-Karte)
;
par_ctl	equ	0d8h		; 8255 Control/Statusregister
par_pa	equ	0a8h		;      Port A
par_pb	equ	0b8h		;      Port B
par_pc	equ	0c8h		;      Port C
;
;
;--------------------------------------------------------------------
;
;
; Echtzeituhr
;
uhr_ctl	equ	19h		; 5832 Controlregister
uhr_dat	equ	18h		;      Datenregister
;
;
;--------------------------------------------------------------------
;
; Thermodrucker
;
therm_d	equ	38h		; Daten
therm_ctl	equ	39h		; Controlregister
;
;
;--------------------------------------------------------------------
;
; Eprom brenner
;
prom_ctl	equ	0bh		; Controlregister
prom_adrl	equ	09h		; Adressen untere Haelfte
prom_adrh	equ	0ah		;          obere Haelfte
prom_dat	equ	08h		; Daten
;
;
;--------------------------------------------------------------------
;
; Einzelschrittmodul
;
ssm_ff	equ	1ah		; Singlestep-Modul FlipFlop
;
;
;--------------------------------------------------------------------
;
; Videokarte
;
vid_dspen	equ 	2ah		; Format/Blanking
					; (Umschaltung Zeichensatz/
					; Abfrage DiSPlayENable
vidctl	equ	2ah		;
vidreg	equ	28h
vidat		equ	29h
					;
lin		equ	50h		; 80d Zeichen pro zeile
lininv	equ	0ffb0h	; - 80d + 1
;
;
;--------------------------------------------------------------------
;
; Hex-display
;
led_zeil	equ	00h		; LED-Zeile
hex_d1	equ	10h		; DIGIT 1
hex_d2	equ	20h		; DIGIT-2
hex_d3	equ	30h		; DIGIT-3
hex_d4	equ	40h		; DIGIT-4
hex_d5	equ	50h		; DIGIT-5
hex_d6	equ	60h		; DIGIT-6
hex_d7	equ	70h		; DIGIT-7
outpor	equ	80h		; DIGIT-7 (+10h)
;
;
;--------------------------------------------------------------------
;
; Hex-Tastatur
;
comand	equ	0bch		; CMD-Keys
hexhi		equ	0dch		; Hex 8..F
hexlo		equ	0ech		; Hex 0..7
;
nxtnr		equ	0h		; NXT-Spalte
fctnr		equ	2h		; FCT-Spalte
adrnr		equ	4h		; ADR-Spalte
runr		equ	6h		; RUN-Spalte
diodnr	equ	7h		; Ge-Diode (zur Unterscheidung
;
;
;--------------------------------------------------------------------
;
;
; ASCII-Tastatur			Adressbereich 0ch bis fch
;
ascii		equ	0fch		; oberste Adresse
;					;
;
;--------------------------------------------------------------------
;
;
;
rambeg	equ	2800h		; CPU-RAM
					; Benutzerbereich bis 2C00h
;
;
csts_vec	equ	2c01h		; Sprungleiste Console ueber IO-Byte
ci_vec	equ	2c04h		;
co_vec	equ	2c07h		;
;
batbuf	equ	2d00h		;
buff_poi	equ	2e00h		; Buffer f.Thermo-Drucker
buff_th	equ	2e00h		; Buffer f.Thermo-Drucker
buff_num	equ	2e02h		; Zeichenzaehler
buff_txt	equ	2e03h		; Textbuffer
;
fctbuf	equ	2e20h		; Fct-Tasten
fct_7		equ	2e20h		;
fct_6		equ	2e22h		;
fct_5		equ	2e24h		;
fct_4		equ	2e26h		;
fct_3		equ	2e28h		;
fct_2		equ	2e2ah		;
fct_1		equ	2e2ch		;
fct_97	equ	2e2eh		;
fct_77	equ	2e30h		;
fct_del	equ	2e32h		;
fct_pl	equ	2e34h		;
fct_ss	equ	2e36h		;
fct_0		equ	2e38h		;
fct_9		equ	2e3ah		;
fct_8		equ	2e3ch		;
fct_87	equ	2e3eh		;
;
buff_vid	equ	2e4eh		; Video
hordsp	equ	2e4eh		;
verdsp	equ	2e4fh		;
lin2		equ	2e50h		;
liny		equ	2e52h		;
linz		equ	2e54h		;
update	equ	2e56h		; aktuelle	Cursorposition
buff_ln	equ	2e60h		; Linebuffer 80 Zeichen
buff_mon	equ	2eb0h		; Monitor
buff_ass	equ	2f00h		; Assembler
stack		equ 	2f00h		; Monito Stack
;
buff_usr	equ	2f70h		; Userstack
usrstk	equ	2f70h		;
;
; _r = Sprungleiste im System RAM
; _m = Sprungleiste im Monitor Rot
;
buff_irq_r	equ	2f8ch		; Interuptverteiler
trap_r	equ	2f8ch		; im System-RAM
rst3_r	equ	2f8fh		;
rst4_r	equ	2f92h		; !in Monitor-Sprungleiste
rst5_r	equ	2f95h		; ! sind die Labels
rst55_r	equ	2f98h		; ! mit _m vorhanden
rst6_r	equ	2f9bh		;
rst65_r	equ	2f9eh		;
rst7_r	equ	2fa1h		;
rst75_r	equ	2fa4h		;
;					; Inhalt
reg_a		equ	2fa7h		; Reg	A
reg_b		equ	2fa8h		; Reg	B
reg_c		equ	2fa9h		; Reg	C
reg_d		equ	2faah		; Reg	D
reg_e		equ	2fabh		; Reg	E
reg_f		equ	2fach		; Reg	F
reg_h		equ	2fadh		; Reg	H
reg_l		equ	2faeh		; Reg	L
reg_s		equ	2fafh		; Reg	SP high-Byte
reg_p		equ	2fb0h		; Reg SP low-Byte
;					;
dspbuf	equ	2fb2h		; DSPBUF	LED-Zeile
dig1		equ	2fb3h		; DIG1
dig2		equ	2fb4h		; DIG2
dig3		equ	2fb5h		; DIG3
dig4		equ	2fb6h		; DIG4
dig5		equ	2fb7h		; DIG5
dig6		equ	2fb8h		; DIG6
dig7		equ	2fb9h		; DIG7
data		equ	2fbah		; Daten
;
adres		equ	2fbbh		; Adresse	HI
adrhi		equ	2fbch		; Adresse	LO
modflg	equ	2fbdh		; Betriebsarten	*1)
fctbf		equ	2fbeh		; FCT-Nr.
srcbeg	equ	2fbfh		; Startadresse
srcend	equ	2fc1h		; Endadresse
dstbeg	equ	2fc3h		; Anfang Zieladresse/Parameter
dstend	equ	2fc5h		;
regnr		equ	2fc7h		; Reg-Nr.
ioflg		equ	2fc8h		; I/O-Parameter	*2)
nxtbuf	equ	2fc9h		; FCT-Eingabe
maxbuf	equ	2fcah		; max.	Anz.
keybyt	equ	2fcbh		; Key	true./.invers
ciflg		equ	2fcch		; Flag	f.	CI-Routine
hibuf		equ	2fcdh		; I/O-Hilfsroutine
hbuf		equ	2fcfh		;
hibuf2	equ	2fd0h		; CTE-Sprungziele
hbuf2		equ	2fd1h		;
brkpt1	equ	2fd3h		; BRK-Adresse	#1
hbufe		equ	2fd4h		; HBUFFER	fuer	ESC
opcod1	equ	2fd5h		; OpCcode-Buf	#1
brkpt2	equ	2fd6h		; BRK-Adresse	#2
hbuf3		equ	2fd7h		;
opcod2	equ	2fd8h		; OpCode-Buf	#2
second	equ	2fdah		; Sekunde
uhrbuff	equ	2fdch		; Uhr-BCD
uhrseke	equ	2fdch		; Sekunden		Einer
uhrsekz	equ	2fddh		; 			Zehner
uhrmine	equ	2fdeh		; Minuten		Einer
uhrminz	equ	2fdfh		; 			Zehner
uhrstde	equ	2fe0h		; Stunden		Einer
uhrstdz	equ	2fe1h		; 			Zehner
uhrklte	equ	2fe2h		; Kalendertag	1-7
uhrwte	equ	2fe3h		; Wochentag		Einer
uhrwtz	equ	2fe4h		; 			Zehner
uhrmone	equ	2fe5h		; Monat		Einer
uhrmonz	equ	2fe6h		; 			Zehner
uhrjare	equ	2fe7h		; Jahr		Einer
uhrjarz	equ	2fe8h		; 			Zehner
;
uhrasc	equ	2fe9h		; Uhr-ASCII	als String abgelegt
;
vidram	equ	3000h		; Anfang Video-RAM
dedwn		equ	313fh		;
bcup		equ	3140h		;
vhome		equ	3140h		; ! Klärungsbedarf 07.02.18
hlup		equ	3190h		;
hldwn		equ	372fh		;
;linz		equ	3730h		; unten	links
bcdwn		equ	377fh		;
vidend	equ	3780h		; hinter	Bildausschnitt
deup		equ	3780h		;
;
; Buffer adressen
;
ccp60k	equ	0d400h	; Bank 1 Startadresse 60k CP/M
bios60k	equ	0ea00h	; Bank 1 BIOS Kaltstart
buffer	equ	0d400h  	; Bank 0 wg. BIOS Anpassungen
zbuff		equ	2e10h		; Zeilenbuffer
;
; fuer Floppy-Routinen
;
fdcbuf	equ	2f70h		; bzw. UserStack
trknr 	equ	2f70h		; Spurnummer
secnr 	equ	2f71h		; Sektornummer
sidnr 	equ	2f72h		; Seite 0/1
selbyt	equ	2f73h		; SelectByte Bit1,2 = Laufwerksnummer
selout	equ	2f74h
track0	equ	2f75h
track1	equ	2f76h
track2	equ	2f77h
track3	equ	2f78h
rwbef 	equ	2f79h
datadr	equ	2f7ah		; Buffer-Adresse r/w Sektoren
intprg	equ	2f7ch
rwsub 	equ	2f7dh
rwsub1	equ	2f7eh
;hibuf 	equ	2f81h		; siehe oben
bufequt	equ	2f82h
bufsrc	equ	2f83h		; IM CF-Betrieb = Anzahl der Sektoren die uebertragen werden
cpyend	equ	2f84h		;
;
timout 	equ	32h		;
dly100 	equ	13h		;
seczal 	equ	16 		;
secldd 	equ	1  		; 256 Bytes
;
;
; Variable fuer IDE Funktionen
;
IDE_A0		EQU	00000001B 	; A0 direct to IDE HDD
IDE_A1		EQU	00000010B 	; A1 dto.
IDE_A2		EQU	00000100B 	; A2 dto.
IDE_CS0		EQU	00001000B 	; CS0 to Inverter
IDE_CS1		EQU	00010000B 	; CS1 dto.
IDE_WR		EQU	00100000B 	; WR dto.
IDE_RD		EQU	01000000B 	; RD dto.
IDE_RST		EQU	10000000B 	; RST dto.
;
IDE_DATA		EQU	IDE_CS0
IDE_ERR		EQU	IDE_CS0 + IDE_A0
IDE_SEC_CNT		EQU	IDE_CS0 + IDE_A1
IDE_SECTOR		EQU	IDE_CS0 + IDE_A1 + IDE_A0
IDE_CYL_LSB		EQU	IDE_CS0 + IDE_A2
IDE_CYL_MSB		EQU	IDE_CS0 + IDE_A2 + IDE_A0
IDE_HEAD		EQU	IDE_CS0 + IDE_A2 + IDE_A1
IDE_COMMAND		EQU	IDE_CS0 + IDE_A2 + IDE_A1 + IDE_A0
IDE_STATUS		EQU	IDE_CS0 + IDE_A2 + IDE_A1 + IDE_A0
IDE_CONTROL		EQU	IDE_CS1 + IDE_A2 + IDE_A1
IDE_ASTATUS		EQU	IDE_CS1 + IDE_A2 + IDE_A1 + IDE_A0
;
IDE_CMD_RECAL	EQU	010H
IDE_CMD_READ	EQU	020H
IDE_CMD_WRITE	EQU	030H
IDE_CMD_INIT	EQU	091H
IDE_CMD_ID		EQU	0ECH
IDE_CMD_SPINDN	EQU	0E0H
IDE_CMD_SPINUP	EQU	0E1H
;
;
; fuer SYS-DISK
;
s_ccp		equ	0D400h	; Start CCP
;
; eingelesene Parameter
;
;
s_qlw		equ	2900h	; Quell_LW
s_zlw		equ	2901h	; Ziel_LW
s_tr		equ	2902h	; Track
s_sek		equ	2903h	; Start_Sektor
s_anz		equ	2904h	; Anzahl der zu ladenden Sektoren
s_fss		equ	2905h	; SS=0, equ=1
s_fsl		equ	2906h	; Sektorlaende 0=128,1=256,2=512,3=1024Byte
s_fsek	equ	2907h	; Anzahl Sektoren/Spur
s_zadr	equ	2908h	; Zieladresse CCP
;
; TEMP_Buffer fuerParameter
;
seklng	equ	290bh	; Sektorlaenge aus s_fsek
;
s_tlw		equ	290ch	; Quell/Ziel_LW
s_ttr		equ	290dh	; Track
s_tsek	equ	290eh	; Start_Sektor
s_tanz	equ	290fh	; Anzahl der zu ladenden Sektoren
s_tfss	equ	2910h	; SS=0, equ=1
s_tfsl	equ	2911h	; Sektorlaende 0=128,1=256,2=512,3=1024Byte
s_tfsek	equ	2912h	; Anzahl Sektoren/Spur
s_tzadr	equ	2913h	; Zieladresse CCP


;

; dynamische Anzeie ss/DS,Tr,Sek
;
;
sc_msg	equ	2918h   	;
sc_ss		equ	2919h		; SS/DS
sc_tr		equ	291bh		; TR
sc_sek	equ	291dh		; Sek
sc_emsg	equ	291eh		;
;

s_srcbeg	equ	2920h		; Par.1
s_srcend	equ	2922h		; Par.2
s_dstbeg	equ	2924h		; Par.3
;
; Buffer fuer Read/Write_Subroutine
;
srw_sub:	equ	2930h	; cdh (call)
;		equ	2931h	; Adresse lesen/schreiben
;		equ	2932h	;
;		equ	2933h	; c9h (ret)
;
;
cpybuf	equ	8000h		;
;
;
;---------------------------------------------------------
; System 	= Systemspuren bearbeiten
;		- Lesen der Systemspuren von LW 0-3 (A-D)
;		- Schreiben der Systemspuren
;		- mit Intel-Hexlader BIOS zufuegen
;		- Parameter fuer LW, Format, Ziel etc. einstellen
;
;
	org	0A000h		; Testadresse spaeterin Monitor
					; integrieren
;
s_kalt:	lxi 	sp,stack	;Kaltstart
       	call	init
		xra 	a       	;Hilfsbank 0 einstellen
		out 	fdc_ctl  	;(d.h. FDC-Software)
		lxi 	sp,stack	;
		lxi	h,s_msg		;
		call	string_v
		lxi 	h,s_msgh	; Hilfen
		call	string_v		;
		;
s_main:	LXI	SP,STACK
		LXI	H,s_main
		PUSH	H
		LXI	H,s_prompt
		CALL	STRING_v
		CALL	CRSON_v
		CALL	CI
		MOV	C,A
		CALL	CO
		CPI	1BH		; ^C Abbruch
		JZ	s_kalt
		ANI	5FH
		cpi	"H"		;
		jz	s_help		; Menue anzeigen
		CPI	"M"
		JZ	ende		; zuruck zum Monitor
		CPI	"P"
		JZ	s_para	; Parameter eingeben
		CPI	"R"
		JZ	s_read	; Systemspuren lesen
		CPI	"I"
		JZ	s_intel	; Intel-Hex aufrufen
		CPI	"W"
		JZ	s_write	; Systemspuren schreiben
		MVI	A,20H
		CALL	ERROR_v
		JMP	s_main
;
s_help	lxi 	h,s_msgh	; Hilfen
       	call	string_v		;
		jmp	s_main

;-----------------------------------------------------------------
;
; Systemspuren Diskette lesen/schreiben
;

s_read:	call	sr_ini	; Parameter aufbereiten
		lxi 	h,sr_msg	;
       	call	string_v	;
		lxi	h,rdsek_f	;
		shld	srw_sub+1	;
		lda	s_qlw		; Quell_LW aufbereiten
		sta	s_tlw
		;
		jmp	s_wr2		;
;
s_write:	call	sr_ini	; Parameter aufbereiten
		lxi 	h,sw_msg	;
		call	string_v	;
		lxi	h,wrsek_f	;
		shld	srw_sub+1	;
		lda	s_zlw		; Ziel_LW aufbereiten
		sta	s_tlw		;

s_wr2:	lda	s_tfsek	; max Sektor/Tr. + 1
		mov	b,a		;
		lhld	seklng	; Sektorlaenge 128-1024
		xchg			;
		xra	a		; SS-Flag loeschen
		sta	s_tfss	;
		;
s_wrlp:	push	b		;
		push	d		; Sichern
		call	s_selb	;
		call	s_par2	; restlichen Parameter uebergeben
		call	srw_sub	; Sektor lesen/schreiben
		;
		call	sc_anz	;
		;
		pop	d		;
		pop	b		;
		lhld	s_tzadr	; Sektorlaenge auf Zieladresse addieren
		dad	d		;
		shld	s_tzadr	;
		lda	s_tanz	; alle Sektoren verarbeitet ?
		dcr	a		;
		jz	s_wre1	; ja --> Ende
		sta	s_tanz	;
		;
		lda	s_tsek	; alle Sektoren der Spur gelesen ?
		inr	a		;
		sta	s_tsek	; Sektor + 1
		cmp	b		;
		jc	s_wrlp	; (a)<(b) ja _-> weiter
		;
		lda	s_tfss	; DS-Flag ?
		cpi	01h		;
		jz	s_ntr		; ja, weiter mit neuem Track
		;
		lda	s_fss		; DS ?
		cpi	01h		;
		jz	s_wrl2	; ja, zweite Seite bearbeiten
;
; SS-Flag = Nein
; -Sektor/Track laden
; -Track + 1
; -SS-Flag aus Parameter setzen
;
s_ntr:	lda	s_ttr		; Track + 1
		inr	a		;
		sta	s_ttr		;
		lda	s_tfsek	; Anz Sek/Tr +1 laden
		mov	b,a		;
		mvi	a,01h		;
		sta	s_tsek	; Sektor 1
		xra	a		; DS_Flag löschen
		sta	s_tfss	;
		jmp	s_wrlp	; --> weiter

;
; DS = JA
; -Sektor/Track laden
; -Seite 1 -> SelectByte
;
s_wrl2:	sta	s_tfss	; DS_Flag setzen
		lda	s_tfsek	; Anz Sek/Tr +1 laden
		mov	b,a		;
		mvi	a,01h		;
		sta	s_tsek	; Sektor 1
		jmp	s_wrlp	; --> weiter
;
; alle Sektoren gelsesen --> Ende
;
s_wre1:	lxi 	h,s1_msg	; OK
       	call	string_v
		jmp	s_main	; --> Ende
;
; lesen/schreiben Subroutine vorbereiten
;
srw_ini:	lxi	h,srw_sub	; Adresse der Subroutine im RAM
		mvi	a,0cdh	; [call]
		mov	m,a		;
		inx	h		;
		inx	h		;
		inx	h		;
		mvi	a,0c9h	; [ret]
		mov	m,a		;
		ret
;
;
; Parameter in Temp-Buffer bereitstellen
;
sr_ini:	lda	s_anz		; Anzahl der sektoren
		sta	s_tanz		;
		lda	s_tr		; Start-Track
		sta	s_ttr		;
		lda	s_sek		; Start Sektor
		sta	s_tsek	;
		lda	s_fsek	; Sek/Tr
		inr	a		; + 1
		sta	s_tfsek	;
		lhld	s_zadr	; Zieladresse
		shld	s_tzadr	;
		lda	s_fsl		;
		cpi	0h		;
		jz	sl128		;
		cpi	1h		;
		jz	sl256		;
		cpi	2h		;
		jz	sl512		;
		cpi	3h		;
		lxi	h,1024	;
sr_inie:	shld	seklng	;
		ret

sl128:	lxi	h,128		; Sektorlaende vorbereiten
		jmp	sr_inie	;
sl256:	lxi	h,256		;
		jmp	sr_inie	;
sl512:	lxi	h,512		;
		jmp	sr_inie	;
sl1024:	lxi	h,1024	;
		jmp	sr_inie	;

;
; Selectbyte aufbereiten
;
s_selb:	lda	s_tlw		; Quell/Ziel-LW laden
		ani	03h		; nur LW 0-3
		ral			; Bitposition berichtigen
		mov	b,a		;
		lda	s_tfss	; SS,DS hinzufuegen
		ani	01h		;
		ral			; Bitposition
		ral			;
		ral			;
		ral			;
		ral			;
		ora	b		;
		mov	b,a		; SelectByte fertig
		ret
;
; s-par = Restlichen Parameter uebergeben fuer Blckweise lesen/schreiben
; spar2 = fuer sektoerweise lesen/schreiben
;
s_par:	lda	s_tanz	; Anzahl der Sektoren
		mov	c,a		;
s_par2:	lda	s_ttr		; Track laden
		mov	d,a		;
		lda	s_tsek	; Sektor laden
		mov	e,a		;
		lhld	s_tzadr	; Zieladresse
		ret
;-----------------------------------------------------------------
; SS,Tr,Sek anzeigen
; ! Sektor > 15(0fh) wird als "G" angezeigt
;
sc_anz:	push	psw
		push	b
		push	d
		push	h
		lxi	h,linz	;
		shld	update	;
		lda	s_tfss
		call	b_asc
		sta	sc_ss		;
		lda	s_ttr		;
		call	b_asc
		sta	sc_tr		;
		lda	s_tsek	;
		call	b_asc
		sta	sc_sek	;
		mvi	a,00
		sta	sc_emsg
		lxi	h,sc_msg
		call	string_v
		pop	h
		pop	d
		pop	b
		pop	psw
		ret
;
b_asc:	cpi	0ah
		jc	b_asz
		adi	07h
b_asz:	adi	30h
		ret
;
;-----------------------------------------------------------------
;
s_intel:	call	ihex		;
		jmp	s_main	; Ruecksprung aus Intel-HEX
					; im Moitor anpassen
					; damit er hier bleibt
;
;
ende:		jmp	warm_v	; zurueck zum Monitor
;
;-----------------------------------------------------------------------
;
; Parameter fuer Systemspuren
;
s_para:	nop
s0_k:		lxi 	h,s0_msg	; Ueberschift
       	call	string_v	;
		;
s_p1:	lxi 	h,sq_msg		;LW ?
       	call	string_v	;
	;
		call	s_get		; Daten eingeben
		call	s_proc	; Daten aus Eingabezeile lese,pruefen
		jz	s_err		;
		;
		lda	s_srcbeg	; Quell-LW sichern
		cpi	04h		;
		jnc	s_err
		sta	s_qlw		;
		lda	s_srcend	; Ziel-LW sichern
		cpi	04h		;
		jnc	s_err
		sta	s_zlw		;
	;
s_p2:		lxi 	h,st_msg	; Track/Sektor
       	call	string_v
		call	s_get		; Daten eingeben
		call	s_proc	; Daten aus Eingabezeile lese,pruefen
		jz	s_err		;
		;
		lda	s_srcbeg	; Quell-LW sichern
		sta	s_tr		;
		lda	s_srcend	;
		sta	s_sek		;
		;
s_p3: 	lxi 	h,sa_msg	; Anzahl Sektoren
       	call	string_v
		call	s_get		; Daten eingeben
		call	s_proc	; Daten aus Eingabezeile lese,pruefen
		jz	s_err		;
		;
		lda	s_srcbeg	;
		sta	s_anz		;
	;
s_p4:		lxi 	h,sf_msg	;
       	call	string_v
		call	s_get		; Daten eingeben
		call	s_proc	; Daten aus Eingabezeile lese,pruefen
		jz	s_err		;
		;
		lda	s_srcbeg	;
		cpi	02h		;
		jnc	s_err		;
		sta	s_fss		;
		lda	s_srcend	;
		cpi	04h		;
		jnc	s_err		;
		sta	s_fsl		;
		lda	s_dstbeg	;
		cpi	11h		;
		jnc	s_err		;
		sta	s_fsek		;
		;
s_p5:		lxi 	h,sz_msg	;
       	call	string_v
		call	s_get		; Daten eingeben
		call	s_proc	; Daten aus Eingabezeile lese,pruefen
		jz	s_err		;
		;
		lhld	s_srcbeg	;
		shld	s_zadr		;
		;
		lxi 	h,s1_msg	; OK
		call	string_v
		jmp	s_main	; --> Ende
;
s_get:	call	s_crsp	; Cursor auf Anfang - Eingabe
s_glp: 	call	ci      	; Taste einlesen
       	mov 	c,a     	; Uebergabe an CO
       	call	co      	; Echo ausgeben
	;
       	cpi 	1bh     	; CTL+C?
       	jz  	warm_v	; zuruek zum Monitor
	;
       	cpi 	0dh     	; Return?
       	jnz 	s_glp   	; kein Ret: JMP
       	call	crsoff_v
		ret

;
s_err:	call	error_v	; Fehlermeldung aus VIDEOMonitor
		jmp	s_kalt	;
;
s_crsp	push	h		; Cursor auf Anfang
		push	d		;
		lhld	linz		;
		lxi	d,15		;
		dad	d		;
		shld	update	;
		call	crspos_v	;
		pop	d		;
		pop	h		;
		call	crson_v		;
		ret
;-------------------------------------------------------



;****************************************************
;
;      Initialisierung
;
;****************************************************
; Standardwerte festlegen [Moppel]
init:		call	inimsg	;
		xra	a		; 0
		sta	s_tr		; Start Track
		inr	a		; 1
		sta	s_fss		; DS
		sta	s_qlw		; Quell_/
		sta	s_zlw		; Ziel-LW
		inr	a		; 2
		sta	s_sek		; Start Sektor
		inr	a		; 3
		sta	s_fsl		; 3=1024
		mvi	a,9		;
		sta	s_anz		; Anzahl Sektoren
		mvi	a,5		; 16 sektoren
		sta	s_fsek		;
		lxi	h,0D400h	;  Star CCP
		shld	s_zadr		;
		call	srw_ini		;
		ret
;
; Dynamische Anzeige ss/DS,Tr,Sek vorbereiten
;
inimsg:	lxi	h,sc_msg	;
		mvi	m,0dh		;
		inx	h		;
		mvi	m,00h		; (SS/DD)
		inx	h		;
		mvi	m,2ch		; ","
		inx	h		;
		mvi	m,00h		;
		inx	h		; (TR)
		mvi	m,2ch		;
		inx	h		; (Sek)
		inx	h		;
		inx	h		;
		mvi	m,00h		; String Ende
		ret





;
;***************************************************
;
; Verarbeitung der Eingabezeile
;
;***************************************************

;
s_proc:	lhld 	linz 		;Eingabezeile
       	lxi  	d,20h		;max. 3 Vierstellige Param.
       	dad  	d    		;H&L auf Blank hinter Param.
       	mvi  	c,12h		;Laenge ohne "E  >"
       	call	s_gf 		;Parameter einlesen
       	ret       		;Fehler: Z=1



crlf:		mvi	c,0dh
		call	co
		mvi	c,0ah	;
		call	co
		ret


;***************************************************
;
;     s-gf  Parameter vom Bildschirm einlesen
;	aus Videomonitor entnommen
;
;***************************************************
;
;  Einsprung: H&L zeigen auf Blank hinter Parameter
;             REG C haelt Parameter-Laenge
;
;  Ruecksprung:Z=1 heisst Fehler (Fehlercode in REG A)
;             sonst stehen die Parameter 1,2 und 3
;             in den Zellen SRCBEG,SRCEND u. DSTBEG
;
s_gf:		push h
       	lxi  h,0h      ;Parameter-Buffer loeschen
       	shld s_srcbeg
       	shld s_srcend
      	shld s_dstbeg
       	pop  h
;
       	mov  a,m       ;Zeichen vom Bildschirm holen
       	cpi  20h       ;Blank?
       	jz   inloop    ;Blank=o.k, d.h. JMP
       	xra  a         ;FLAGs setzen
       	mvi  a,11h     ;String zu lang
       	ret            ;Fehler: Z=1
;
inloop:	lxi  d,0h      ;Displacement
       	xchg
       	shld dig1      ;Hilfs-Buffer loeschen
       	shld dig3
       	xchg
;
inlop: 	dcx  h
       	dcr  c
       	jp   inlop2
       	xra  a         ;FLAGs setzen
       	mvi  a,10h     ;Input fehlt
       	ret            ;Fehler: Z=1
;
inlop2:	mov  a,m
       	cpi  20h       ;Blank?
       	jz   inlop     ;ja:JMP (nachruecken)
       	mov  b,a       ;Zeichen retten
;
       	xra  a         ;REG A loeschen
       	cmp  c         ;Param.-Anfang erreicht?
       	mov  a,b
       	jnz  incte     ;nein: JMP
       	call assemb    ;Digits zusammensetzen
       	inr  c         ;FLAGs loeschen
parend:	ret
;
incte: 	cpi  2ch       ;Komma?
       	jz   inct      ;ja: JMP
       	cpi  2eh       ;Punkt?
       	jz   inct      ;ja: JMP
       	call hxtst     ;Input ueberpruefen
       	rz             ;Fehler: Z=1
       	jmp  inlop     ;sonst weiter
;
inct:  	call assemb    ;Digits zusammensetzen
       	jmp  inloop
;
assemb:	push psw
       	push h
       	push d
       	lxi  h,dig1    ;Digits zu Doppelwort
       	mov  e,m       ;zusammensetzen
       	inx  h
       	mov  a,m
       	rlc            ;oberes Nibble im
       	rlc            ;unteren Wort
       	rlc
       	rlc
       	ora  e         ;unteres Wort kpl.
       	mov  e,a
       	inx  h
       	mov  d,m
       	inx  h
       	mov  a,m
       	rlc            ;oberes Nibble im
       	rlc            ;oberen Wort
       	rlc
       	rlc
       	ora  d         ;oberes Wort kpl.
       	mov  d,a
;
		lhld s_srcend    ;Parameter nachschieben
		shld s_dstbeg
		lhld s_srcbeg
		shld s_srcend
		xchg
		shld s_srcbeg
		pop  d
		pop  h
		pop  psw
		ret
;
hxtes_:	lxi  d,0h      ;f.externen Einsprung
hxtst: 	ani  5fh       ;Grossbuchstabe
       	cpi  10h       ;"0"
       	jc   hexerr    ;Code zu klein:JMP
       	cpi  1ah       ;"9"+1
       	jc   hexcte    ;Code o.k.:JMP
       	adi  0c9h      ;A...F adjust
       	cpi  10h       ;"F"+1
       	jnc  hexerr    ;Code zu gro~:JMP
       	cpi  0ah       ;korr. "A"
       	jnc  insft     ;A...F: JMP
hexerr:	xra  a         ;FLAGs setzen
       	mvi  a,12h     ;kein HEX-Digit
       	ret            ;Fehler: Z=1
;
hexcte:	sui  10h       ;Rest der "3x"
insft: 	push h         ;Param. einsammeln
       	lxi  h,dig1    ;Parameter-Buffer
       	dad  d         ;Displacement
       	mov  m,a
       	inx  d
       	pop  h
       	mov  b,a
       	xra  a
       	inr  a         ;FLAGs loeschen
       	mov  a,b
       	ret            ;REG A: HEX-Nibble
;


;------------------------------------------------------
; Texte fuer Funktionen
;
;
s_msg:	db	0dh		; Ueberschrift
		db	"Systemspuren bearbeiten V1.1"
		db	0dh		;
		db	"(c)2023 Werner.Roemer"
		db	0ah		;
		db	0h

s0_msg:	db	0dh		; Ueberschrift
		db	"Systemparameter (HEX)"
		db	0dh		;
		db	0h

s1_msg:	db	0dh		; Fertigmeldung
		db	"OK"
		db	0dh		;
		db	0h

sq_msg:	db	0dh		; Quell-Ziel LW
		db	"Quell Ziel LW >1"
		db	2ch
		db	"1"
		db	0h

st_msg:	db	0dh       	; System tr./Sek.
		db	"Track Sek     >0"
		db	2ch
		db	"2"
		db	0h

sa_msg:	db	0dh		; Anzahl der zu ladenden Sektoren
		db	"Anzahl Sek    >28"
		db	0h

sz_msg:	db	0dh       	; RAM Zieladresse
		db	"Ziel Adr      >D400"
		db	0h

sf_msg:	db	0dh       	; SS/DS, Sektorlaenge, Anzahl Sek.
		db	"Format        >0"
		db	2ch
		db	"1"
		db	2ch
		db	"10"
		db	0h

s_prompt:	db	0dh		; Prompt
		db	"S>"
		db	0h

s_msgh:	db	0dh		; Hilfe
		db	"m = zurueck zum Monitor"
		db	0dh		;
		db	"p = Parameter eingeben"
		db	0dh
		db	"    (ss/ds, Sek.laenge, Sek.per Track)"
		db	0dh		;
		db	"r = Systemspuren lesen"
		db	0dh		;
		db	"i = Intel-Hex"
		db	0dh		;
		db	"w = Systemspuren schreiben"
		db	0dh		;
		db	"h = Hilfe "
		db	0h

sr_msg:	db	0dh		;
		db	"Systemspur lesen"
		db	0h

sw_msg:	db	0dh		;
		db	"Systemspur schreiben"
		db	0h

si_msg:	db	0dh		;
		db	"Intel-Hex laden0"
		db	0h
;

;------------------------------------------------------

;
end